@@ -259,19 +259,22 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 	}
 
 #ifdef HAVE_LIBEXIF
-	file->ed = exif_get_data(file->filename);
-
-	if (file->ed) {
-		entry = exif_content_get_entry(file->ed->ifd[EXIF_IFD_0], 0x0112);
-		if (entry != NULL) {
-			if (*(entry->data) == 3)
-				gib_imlib_image_orientate(*im, 2);
-			else if (*(entry->data) == 6)
-				gib_imlib_image_orientate(*im, 1);
-			else if (*(entry->data) == 8)
-				gib_imlib_image_orientate(*im, 3);
-		}
+	int orientation = 0;
+	ExifData *exifData = exif_data_new_from_file(file->filename);
+	if (exifData) {
+		ExifByteOrder byteOrder = exif_data_get_byte_order(exifData);
+		ExifEntry *exifEntry = exif_data_get_entry(exifData, EXIF_TAG_ORIENTATION);
+		if (exifEntry && opt.auto_rotate)
+			orientation = exif_get_short(exifEntry->data, byteOrder);
 	}
+	file->ed = exifData;
+
+	if (orientation == 3)
+		gib_imlib_image_orientate(*im, 2);
+	else if (orientation == 6)
+		gib_imlib_image_orientate(*im, 1);
+	else if (orientation == 8)
+		gib_imlib_image_orientate(*im, 3);
 #endif
 
 	D(("Loaded ok\n"));
@@ -1021,28 +1024,29 @@ void feh_display_status(char stat)
 
 void feh_edit_inplace(winwidget w, int op)
 {
-	int ret;
-	Imlib_Image old;
-	Imlib_Load_Error err;
+	int tmp;
+	Imlib_Image old = NULL;
+	Imlib_Load_Error err = IMLIB_LOAD_ERROR_NONE;
 	if (!w->file || !w->file->data || !FEH_FILE(w->file->data)->filename)
 		return;
 
-	if (!strcmp(gib_imlib_image_format(w->im), "jpeg")) {
+	if (!strcmp(gib_imlib_image_format(w->im), "jpeg") &&
+			!path_is_url(FEH_FILE(w->file->data)->filename)) {
 		feh_edit_inplace_lossless(w, op);
 		feh_reload_image(w, 1, 1);
 		return;
 	}
 
-	ret = feh_load_image(&old, FEH_FILE(w->file->data));
-	if (ret) {
-		if (op == INPLACE_EDIT_FLIP) {
-			imlib_context_set_image(old);
+	old = imlib_load_image_with_error_return(FEH_FILE(w->file->data)->filename, &err);
+
+	if ((old != NULL) && (err == IMLIB_LOAD_ERROR_NONE)) {
+		imlib_context_set_image(old);
+		if (op == INPLACE_EDIT_FLIP)
 			imlib_image_flip_vertical();
-		} else if (op == INPLACE_EDIT_MIRROR) {
-			imlib_context_set_image(old);
+		else if (op == INPLACE_EDIT_MIRROR)
 			imlib_image_flip_horizontal();
-		} else
-			gib_imlib_image_orientate(old, op);
+		else
+			imlib_image_orientate(op);
 		gib_imlib_save_image_with_error_return(old,
 			FEH_FILE(w->file->data)->filename, &err);
 		gib_imlib_free_image(old);
@@ -1051,7 +1055,23 @@ void feh_edit_inplace(winwidget w, int op)
 				w, err);
 		feh_reload_image(w, 1, 1);
 	} else {
-		im_weprintf(w, "failed to load image from disk to edit it in place");
+		/*
+		 * Image was opened using curl/magick or has been deleted after
+		 * opening it
+		 */
+		imlib_context_set_image(w->im);
+		if (op == INPLACE_EDIT_FLIP)
+			imlib_image_flip_vertical();
+		else if (op == INPLACE_EDIT_MIRROR)
+			imlib_image_flip_horizontal();
+		else {
+			imlib_image_orientate(op);
+			tmp = w->im_w;
+			FEH_FILE(w->file->data)->info->width = w->im_w = w->im_h;
+			FEH_FILE(w->file->data)->info->height = w->im_h = tmp;
+		}
+		im_weprintf(w, "unable to edit in place. Changes have not been saved.");
+		winwidget_render_image(w, 1, 0);
 	}
 
 	return;
